@@ -22,9 +22,9 @@
 
 #include <KLocalizedString>
 #include <KIcon>
-
 #include <core/kdebugnamespace.h>
 
+
 K_PLUGIN_FACTORY( KdeConnectPluginFactory, registerPlugin< TelephonyPlugin >(); )
 K_EXPORT_PLUGIN( KdeConnectPluginFactory("kdeconnect_telephony", "kdeconnect-plugins") )
 
@@ -60,13 +60,16 @@ KNotification* TelephonyPlugin::createNotification(const NetworkPackage& np)
     } else if (event == "talking") {
         return NULL;
     } else {
-        //TODO: return NULL if !debug
-        type = "unknownEvent";
+#ifdef NDEBUG
+        return NULL;
+#else
+        type = "callReceived";
         icon = "pda";
         content = i18n("Unknown telephony event: %2", event);
+#endif
     }
 
-    kDebug(kdeconnect_kded()) << "Creating notification with type:" << type;
+    kDebug(debugArea()) << "Creating notification with type:" << type;
 
     KNotification* notification = new KNotification(type, KNotification::CloseOnTimeout, this); //, KNotification::Persistent
     notification->setPixmap(KIcon(icon).pixmap(48, 48));
@@ -74,6 +77,11 @@ KNotification* TelephonyPlugin::createNotification(const NetworkPackage& np)
     notification->setTitle(title);
     notification->setText(content);
 
+    if (event == "ringing") {
+        notification->setActions( QStringList(i18n("Mute call")) );
+        connect(notification, SIGNAL(action1Activated()), this, SLOT(sendMutePackage()));
+    }
+
     return notification;
 
 }
@@ -96,3 +104,10 @@ bool TelephonyPlugin::receivePackage(const NetworkPackage& np)
     return true;
 
 }
+
+void TelephonyPlugin::sendMutePackage()
+{
+    NetworkPackage package(PACKAGE_TYPE_TELEPHONY);
+    package.set<QString>( "action", "mute" );
+    sendPackage(package);
+}
